==> kops-1.24.3.tar.gz: kops-1.24.3/pkg/resources/openstack/dns.go <==
/*
Copyright 2019 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package openstack

import (
	"fmt"

	"k8s.io/kops/pkg/dns"

	"github.com/gophercloud/gophercloud/openstack/dns/v2/recordsets"
	"github.com/gophercloud/gophercloud/openstack/dns/v2/zones"
	"k8s.io/kops/pkg/resources"
	"k8s.io/kops/upup/pkg/fi"
	"k8s.io/kops/upup/pkg/fi/cloudup/openstack"
)

const (
	typeDNSRecord = "dNSRecord"
)

func (os *clusterDiscoveryOS) ListDNSRecordsets() ([]*resources.Resource, error) {
	// if dnsclient does not exist (designate disabled) or using gossip DNS
	if os.osCloud.DNSClient() == nil || dns.IsGossipHostname(os.clusterName) {
		return nil, nil
	}

	zopts := zones.ListOpts{
		Name: os.clusterName,
	}

	zs, err := os.osCloud.ListDNSZones(zopts)
	if err != nil {
		return nil, fmt.Errorf("failed to list dns zones: %s", err)
	}

	if len(zs) == 0 {
		return nil, fmt.Errorf("dns zone not found: %s", os.clusterName)
	}

	z := zs[0]

	rrs, err := os.osCloud.ListDNSRecordsets(z.ID, nil)
	if err != nil {
		return nil, fmt.Errorf("failed to extract recordsets pages for zone %s: %v", z.Name, err)
	}

	var resourceTrackers []*resources.Resource
	for _, rr := range rrs {
		if rr.Type != "A" {
			continue
		}

		resourceTracker := &resources.Resource{
			Name: rr.Name,
			ID:   rr.ID,
			Type: typeDNSRecord,
			Deleter: func(cloud fi.Cloud, r *resources.Resource) error {
				// TODO: not tested and this should have retry similar to what we have in another resources
				return recordsets.Delete(cloud.(openstack.OpenstackCloud).DNSClient(), z.ID, rr.ID).ExtractErr()
			},
			Obj: rr,
		}

		resourceTrackers = append(resourceTrackers, resourceTracker)
	}

	return resourceTrackers, nil
}

==> kops-1.26.4.tar.gz: kops-1.26.4/pkg/resources/openstack/dns.go <==
/*
Copyright 2019 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package openstack

import (
	"fmt"

	"k8s.io/kops/pkg/dns"

	"github.com/gophercloud/gophercloud/openstack/dns/v2/recordsets"
	"github.com/gophercloud/gophercloud/openstack/dns/v2/zones"
	"k8s.io/kops/pkg/resources"
	"k8s.io/kops/upup/pkg/fi"
	"k8s.io/kops/upup/pkg/fi/cloudup/openstack"
)

const (
	typeDNSRecord = "dNSRecord"
)

func (os *clusterDiscoveryOS) ListDNSRecordsets() ([]*resources.Resource, error) {
	// if dnsclient does not exist (designate disabled) or using gossip DNS
	if os.osCloud.DNSClient() == nil || dns.IsGossipClusterName(os.clusterName) {
		return nil, nil
	}

	zopts := zones.ListOpts{
		Name: os.clusterName,
	}

	zs, err := os.osCloud.ListDNSZones(zopts)
	if err != nil {
		return nil, fmt.Errorf("failed to list dns zones: %s", err)
	}

	if len(zs) == 0 {
		return nil, fmt.Errorf("dns zone not found: %s", os.clusterName)
	}

	z := zs[0]

	rrs, err := os.osCloud.ListDNSRecordsets(z.ID, nil)
	if err != nil {
		return nil, fmt.Errorf("failed to extract recordsets pages for zone %s: %v", z.Name, err)
	}

	var resourceTrackers []*resources.Resource
	for _, rr := range rrs {
		if rr.Type != "A" {
			continue
		}

		resourceTracker := &resources.Resource{
			Name: rr.Name,
			ID:   rr.ID,
			Type: typeDNSRecord,
			Deleter: func(cloud fi.Cloud, r *resources.Resource) error {
				// TODO: not tested and this should have retry similar to what we have in another resources
				return recordsets.Delete(cloud.(openstack.OpenstackCloud).DNSClient(), z.ID, rr.ID).ExtractErr()
			},
			Obj: rr,
		}

		resourceTrackers = append(resourceTrackers, resourceTracker)
	}

	return resourceTrackers, nil
}
